@@ -2,7 +2,10 @@ from Bubot.Helpers.Helper import get_tzinfo
 from aiohttp import web
 from bson.json_util import dumps, JSONOptions
 
-json_options = JSONOptions(tz_aware=True, tzinfo=get_tzinfo())
+json_options = JSONOptions(
+    tz_aware=False,
+    # tzinfo=get_tzinfo()
+)
 
 
 class DeviceApi:
