@@ -3,7 +3,7 @@ import asyncio
 import json
 import os.path
 from uuid import uuid4
-
+import aioredis
 # from bubot.Catalog.Client.WebServer import API
 from Bubot.Core.DataBase.Mongo import Mongo as Storage
 # from bubot.Core.DataBase.SqlLite import SqlLite as Storage
@@ -25,7 +25,7 @@ from aiohttp import web
 from aiohttp_session import get_session, setup
 
 from .__init__ import __version__ as device_version
-
+from BubotObj.OcfDevice.subtype.Device.RedisQueueMixin import RedisQueueMixin
 
 # from bson import ObjectId
 
@@ -33,7 +33,7 @@ from .__init__ import __version__ as device_version
 # _logger = logging.getLogger(__name__)
 
 
-class WebServer(VirtualServer, QueueMixin):
+class WebServer(RedisQueueMixin, VirtualServer):#, QueueMixin):
     version = device_version
     file = __file__
     template = False
@@ -45,24 +45,27 @@ class WebServer(VirtualServer, QueueMixin):
         # self.cache_schemas = {}
         self.schemas_dir = []
         self.net_devices = {}
-        self.request_queue = asyncio.Queue()
-        self.serial_queue_worker = None
+        # self.request_queue = asyncio.Queue()
+        # self.serial_queue_worker = None
         self.ws = {}
         self.runner = None
         self.storage = None
         VirtualServer.__init__(self, **kwargs)
+        RedisQueueMixin.__init__(self, **kwargs)
 
     async def on_pending(self):
         # self.serial_queue_worker = asyncio.ensure_future(self.queue_worker(self.request_queue, 'request_queue'))
+        await RedisQueueMixin.on_pending(self)
         await self.run_web_server()
-        await super().on_pending()
+        await VirtualServer.on_pending(self)
 
     async def on_cancelled(self):
+        await RedisQueueMixin.on_cancelled(self)
         if self.storage:
             await self.storage.close()
         if self.runner is not None:
             await self.runner.cleanup()
-        await super().on_cancelled()
+        await VirtualServer.on_cancelled(self)
 
     @async_action
     async def run_web_server(self, *, _action):
@@ -76,6 +79,9 @@ class WebServer(VirtualServer, QueueMixin):
             #     self.middleware_index
             # ]
         )
+        redis_url = self.get_param('/oic/con', 'redis_url')
+        if redis_url:
+            self.redis = await aioredis.from_url(redis_url)
         app['device'] = self
         app['sessions'] = {}
         app['fast_storage'] = FastStorage()
